@@ -152,7 +152,11 @@ bool CapiTrunk::idleHandler(TrunkEvent *event)
 				(unsigned char *)"",
 				(unsigned char *)"",
 				(unsigned char *)"",
-				(unsigned char *)"");
+				(unsigned char *)""
+#ifdef  HAVE_ALERT_SENDING_COMPLETE
+                                ,NULL
+#endif
+			);
 		if (err != CapiNoError) {
 			slog(Slog::levelError) << "CAPI: ALERT_REQ err = "
 					 << err << endl;
