@@ -118,6 +118,12 @@ bool DialogicTrunk::stepHandler(TrunkEvent *event)
 			handler = &DialogicTrunk::loadHandler;
 			return true;
 #endif
+		case TRUNK_STEP_REROUTE:
+                       handler = &DialogicTrunk::rerouteHandler;
+                       return true;
+		case TRUNK_STEP_CONFERENCE:
+                       handler = &DialogicTrunk::conferenceHandler;
+                       return true;
 		}
 		return false;
 	case TRUNK_SERVICE_SUCCESS:
