@@ -31,6 +31,9 @@ Keydata("/bayonne/soundcard")
 	{"stack", "64"},
 	{NULL, NULL}};
 
+	if(isFHS())
+		load("/drivers/soundcard");
+
 	load(defkeys);
 }
 
@@ -64,6 +67,9 @@ Driver(), DummyConfig(), Thread(keythreads.priService(), dummyivr.getStack())
 	ports = new DummyTrunk *[port_count];
 	groups = new TrunkGroup *[port_count];
 
+	status = DummyTrunk::status;
+	memset(status, '-', sizeof(DummyTrunk::status));
+
 	if(ports)
 		memset(ports, 0, sizeof(DummyTrunk *) * port_count);
 
@@ -119,7 +125,7 @@ void DummyDriver::stop(void)
 
 	if(ports)
 	{
-		for(count = 0; count < getDeviceCount(); ++count)
+		for(count = 0; count < (unsigned)getDeviceCount(); ++count)
 		{
 			trk = ports[count];
 			if(trk)
@@ -136,7 +142,7 @@ void DummyDriver::run(void)
 {
 	TrunkEvent event;
 	timeout_t timeout;
-	pollfd pfd;
+	pollfd pfd[1];
 	char ch;
 	struct termios n;
 	DummyTrunk *trunk;
@@ -146,7 +152,7 @@ void DummyDriver::run(void)
 	setCancel(cancelImmediate);
 	slog(Slog::levelNotice) << "dummy: start thread" << endl;\
 
-	pfd.fd = 0;
+	pfd[0].fd = 0;
 	
         tcgetattr(0, &t);
         tcgetattr(0, &n);
@@ -165,8 +171,8 @@ void DummyDriver::run(void)
 		}
 
 		snprintf(name, sizeof(name), "dummy%d", port);
-
-		trunk->enterMutex();		
+		
+		trunk->enterMutex();
 		timeout = trunk->getTimer();
 		if(!timeout)
 		{
@@ -174,14 +180,15 @@ void DummyDriver::run(void)
 			event.id = TRUNK_TIMER_EXPIRED;
 			trunk->postEvent(&event);
 		}
-		if(timeout > 500)
-			timeout = 500;
 		trunk->leaveMutex();
 
+		if(timeout > 500)
+			timeout = 500;
 
-                pfd.events = POLLIN | POLLRDNORM;
-                pfd.revents = 0;
-                if(poll(&pfd, 1, timeout) > 0)
+                pfd[0].events = POLLIN | POLLRDNORM;
+                pfd[0].revents = 0;
+
+                if(poll(pfd, 1, timeout) > 0)
 		{
 			::read(0, &ch, 1);
                         switch(ch)
