@@ -225,10 +225,17 @@ Driver(), Thread(keythreads.priService() - 1)
 	int boardtype;
 	int card = 0;
 	int vox = 0;
-	int id = 0;
+	int id = 0, queue;
 	unsigned i, s, portidx;
 	GC_CCLIB_STATUSALL cclibstatus;
 	GC_INFO gcinfo;
+	const char *cp = getLast("queue");
+
+	GC_PARM gcparm;
+	int gc_err;
+	int cclibid;
+	long cclib_err;
+	char *msg;
 
 	level = 0;
 	status = DialogicTrunk::status;
@@ -252,6 +259,13 @@ Driver(), Thread(keythreads.priService() - 1)
 	memset(devmap, 0, sizeof(devices_t) * port_count);
 	memset(spanmaps, 0, sizeof(DialogicISDN *) * getSpanCount());
 
+	if(cp)
+	{
+		queue = atoi(cp);
+		sr_setparm(SRL_DEVICE, SR_QSIZEID, &queue);
+		slog(Slog::levelDebug) << "dialogic: event queue depth set to " << queue << endl;
+	}
+
 #ifndef	SIGNAL
 	slog(Slog::levelDebug) << "globalcall: setting polled mode" << endl;
 	mode = SR_POLLMODE;
@@ -332,22 +346,7 @@ Driver(), Thread(keythreads.priService() - 1)
 				s, i + 1, getSpanProtocol());
 		}
 
-		// Reset port - Resolve problem if the Bayonne was terminated
-        LINEDEV Templinedevp;
-        if (gc_Open(&Templinedevp, devmap[portidx].devname, 0) != GC_SUCCESS) {
-             slog(Slog::levelCritical) << "ERROR OPENING DEVICE" << endl;
-        }
-        if (gc_ResetLineDev(Templinedevp, EV_SYNC) != GC_SUCCESS) {
-             slog(Slog::levelCritical) << "ERROR RESET LINE DEVICE" << endl;
-        }
-        else {
-             slog(Slog::levelCritical) << "LINE RESET" << endl;
-        }
-        if (gc_Close(Templinedevp) != GC_SUCCESS) {
-             slog(Slog::levelCritical) << "ERROR CLOSING DEVICE" << endl;
-        }
-
-		if(gc_OpenEx(&devmap[portidx].linedev, devmap[portidx].devname, EV_ASYNC, 
+		if(gc_OpenEx(&devmap[portidx].linedev, devmap[portidx].devname, EV_SYNC, 
 				(void *)&devmap[portidx]) != GC_SUCCESS)
 		{
 			slog(Slog::levelCritical) << "gc open error" << endl;
@@ -377,8 +376,15 @@ Driver(), Thread(keythreads.priService() - 1)
 		// SR5.1 + a JCT card with this enabled will not detect hangups.
 		// Possibly also the cause of missing hangup on SP1 aswell with the
 		// same board.
-		//gc_SetEvtMsk(devmap[portidx].linedev, GCMSK_ALERTING | GCMSK_BLOCKED |
-		//	GCMSK_DIALING | GCMSK_PROCEEDING | GCMSK_UNBLOCKED, GCACT_SETMSK);
+		// gc_SetEvtMsk(devmap[portidx].linedev, GCMSK_ALERTING | GCMSK_BLOCKED |
+			// GCMSK_DIALING | GCMSK_PROCEEDING | GCMSK_UNBLOCKED, GCACT_SETMSK);
+
+		gcparm.longvalue = 100;  
+		if (gc_SetParm (devmap[portidx].linedev, RECEIVE_INFO_BUF, gcparm) != GC_SUCCESS)  {  
+			gc_ErrorValue(&gc_err, &cclibid, &cclib_err);  
+			gc_ResultMsg(cclibid, cclib_err, &msg);  
+			slog(Slog::levelError) << "Error on SetParm - " << devmap[portidx].linedev << " : " << msg << " (" << cclib_err << ")" << endl;
+		}
 
 		++id;
 	   }
@@ -548,7 +554,7 @@ void DialogicDriver::run(void)
 		evdev = metaevent.evtdev;
 		linedev = metaevent.linedev;
 
-		//slog(Slog::levelDebug) << "got event " << hex << evtype << endl;
+		// slog(Slog::levelDebug) << "got event " << hex << evtype << endl;
 
 		if(metaevent.flags & GCME_GC_EVENT)
 			trunk = maps[linedev];
@@ -566,61 +572,38 @@ void DialogicDriver::run(void)
 
 		switch(evtype)
 		{
-        case GCEV_OPENEX:
-            trunk->getName(buffer);
-            slog(Slog::levelDebug) << buffer << ": GCEV_OPENEX HDL:" << metaevent.linedev << endl;
-            gc_WaitCall(linedev, NULL, NULL, 0, EV_ASYNC);
-            break;
-        case GCEV_OPENEX_FAIL:
-            trunk->getName(buffer);
-            slog(Slog::levelDebug) << buffer << ": GCEV_OPENEX_FAIL HDL:" << metaevent.linedev << endl;
-            break;        
 		case GCEV_FATALERROR:
-            trunk->getName(buffer);
-            slog(Slog::levelDebug) << buffer << ": GCEV_FATALERROR HDL:" << metaevent.linedev <<  endl;
-            break;
 		case GCEV_TASKFAIL:
-            trunk->getName(buffer);
-            slog(Slog::levelDebug) << buffer << ": GCEV_TASKFAIL HDL:" << metaevent.linedev << endl;
-            gc_ResetLineDev(linedev, EV_ASYNC);                       
 			event.id = TRUNK_CALL_FAILURE;
+			EventError(&metaevent);
 			trunk->postEvent(&event);
 			break;
 		case GCEV_BLOCKED:
-            trunk->getName(buffer);
-            slog(Slog::levelDebug) << buffer << ": GCEV_BLOCKED HDL:" << metaevent.linedev  << endl;
+			trunk->getName(buffer);
 			slog(Slog::levelDebug) << buffer << ": blocked" << endl;
 			trunk->_blocked = true;
 			event.id = TRUNK_DEVICE_BLOCKED;
 			trunk->postEvent(&event);
 			break;
 		case GCEV_UNBLOCKED:
-            trunk->getName(buffer);
-            slog(Slog::levelDebug) << buffer << ": GCEV_UNBLOCKED HDL:" << metaevent.linedev << endl;
+			trunk->getName(buffer);
 			slog(Slog::levelDebug) << buffer << ": unblocked" << endl;
 			trunk->_blocked = false;
 			event.id = TRUNK_DEVICE_UNBLOCKED;
 			trunk->postEvent(&event);
 			break;
 		case GCEV_RESETLINEDEV:
-            trunk->getName(buffer);
-            slog(Slog::levelDebug) << buffer << ": GCEV_RESETLINEDEV HDL:" << metaevent.linedev  << endl;
-            gc_WaitCall(linedev, NULL, NULL, 0, EV_ASYNC);
 			trunk->crn = -1;
 			event.id = TRUNK_CALL_RESTART;
 			event.parm.ok = true;
 			trunk->postEvent(&event);
 			break;
 		case GCEV_RESTARTFAIL:
-            trunk->getName(buffer);
-            slog(Slog::levelDebug) << buffer << ": GCEV_RESTARTFAIL HDL:" << metaevent.linedev  << endl;
 			event.id = TRUNK_CALL_RESTART;
 			event.parm.ok = false;
 			trunk->postEvent(&event);
 			break;
 		case GCEV_DISCONNECTED:
-            trunk->getName(buffer);
-            slog(Slog::levelDebug) << buffer << ": GCEV_DISCONNECTED HDL:" << metaevent.linedev  << endl;
 			event.id = TRUNK_STOP_DISCONNECT;
 			trunk->postEvent(&event);
 			break;
@@ -630,12 +613,7 @@ void DialogicDriver::run(void)
 			strcpy(trunk->callingnasposs, "UNKNOWN");
 			strcpy(trunk->contextposs, "NONE");
 			strcpy(trunk->retourposs, "NONE");
-			gcparm.longvalue = 100;  
-			if (gc_SetParm (linedev, RECEIVE_INFO_BUF, gcparm) != GC_SUCCESS)  {  
-				gc_ErrorValue(&gc_err, &cclibid, &cclib_err);  
-				gc_ResultMsg(cclibid, cclib_err, &msg);  
-				slog(Slog::levelError) << "Error on SetParm - " << linedev << " : " << msg << " (" << cclib_err << ")" << endl;
-			}
+
 			if (gc_GetSigInfo(linedev, (char *)&ie_blk, U_IES, &metaevent) != GC_SUCCESS) {
 				gc_ErrorValue(&gc_err, &cclibid, &cclib_err);  
 				gc_ResultMsg(cclibid, cclib_err, &msg);
@@ -656,47 +634,45 @@ void DialogicDriver::run(void)
 				} else slog(Slog::levelDebug) << "No commande Possibilite" << endl;
 			}
 			// End of modification
-            trunk->getName(buffer);
-            slog(Slog::levelDebug) << buffer << ": GCEV_OFFERED HDL:" << metaevent.linedev  << endl;
+
+
+                        // Modif: Detect and store a second CRN due to multiple call on one line 
+                        trunk->crn_hold = -1;
+                        if(trunk->crn != -1){
+                         trunk->crn_hold = metaevent.crn;
+                        }
+                        else{
+                         trunk->crn = metaevent.crn;
+                        }
+                        // End Modif 
+
 			trunk->crn = metaevent.crn;
 			event.id = TRUNK_CALL_OFFER;
 			trunk->postEvent(&event);
 			break;
 		case GCEV_ACCEPT:
-            trunk->getName(buffer);
-            slog(Slog::levelDebug) << buffer << ": GCEV_ACCEPT HDL:" << metaevent.linedev << endl;
 			event.id = TRUNK_CALL_ACCEPT;
 			trunk->postEvent(&event);
 			break;
 		case GCEV_ANSWERED:
-            trunk->getName(buffer);
-            slog(Slog::levelDebug) << buffer << ": GCEV_ANSWERED HDL:" << metaevent.linedev << endl;
 			event.id = TRUNK_OFF_HOOK;
 			trunk->putEvent(&event);
 			break;
 		case GCEV_CONNECTED:
-            trunk->getName(buffer);
-            slog(Slog::levelDebug) << buffer << ": GCEV_CONNECTED HDL:" << metaevent.linedev << endl;
 			event.id = TRUNK_CALL_CONNECT;
 			trunk->putEvent(&event);
 			break;
 		case GCEV_DROPCALL:
-            trunk->getName(buffer);
-            slog(Slog::levelDebug) << buffer << ": GCEV_DROPCALL HDL:" << metaevent.linedev << endl;
 			event.id = TRUNK_CALL_DISCONNECT;
 			trunk->putEvent(&event);
 			break;
 		case GCEV_RELEASECALL:
-            trunk->getName(buffer);
-            slog(Slog::levelDebug) << buffer << ": GCEV_RELEASECALL HDL:" << metaevent.linedev << endl;
 			trunk->crn = -1;
 			event.id = TRUNK_CALL_RELEASE;
 			event.parm.ok = true;
 			trunk->putEvent(&event);
 			break;
 		case GCEV_RELEASECALL_FAIL:
-            trunk->getName(buffer);
-            slog(Slog::levelDebug) << buffer << ": GCEV_REALESECALL_FAIL HDL:" << metaevent.linedev << endl;
 			trunk->crn = -1;
 			trunk->postGCError("gc_ReleaseCallEx");
 			event.id = TRUNK_CALL_RELEASE;
@@ -842,7 +818,18 @@ void DialogicDriver::run(void)
 			case TDX_PLAYTONE:
 			case TDX_DIAL:
 			case TDX_CALLP:
-				event.id = TRUNK_TONE_IDLE;
+				switch(event.id)
+				{
+					case TRUNK_CPA_NOANSWER:
+					case TRUNK_CPA_NODIALTONE:
+					case TRUNK_CPA_NORINGBACK:
+					case TRUNK_CPA_FAILURE:
+					case TRUNK_CPA_BUSYTONE:
+						break;
+
+					default:
+						event.id = TRUNK_TONE_IDLE;
+				}
 				break;
 			case TDX_PLAY:
 			case TDX_RECORD:
@@ -855,6 +842,8 @@ void DialogicDriver::run(void)
 			event.id = TRUNK_TIMER_EXPIRED;
 			trunk->putEvent(&event);
 			break;
+		case CCEV_SETCHANSTATE:
+			break;
 		default:
 			slog(Slog::levelDebug) << "globalcall: unhandled event 0x" << hex << evtype << endl;
 		}
