@@ -140,6 +140,61 @@ bool DialogicTrunk::idleHandler(TrunkEvent *event)
 	{
 	case TRUNK_CALL_RESTART:
 	case TRUNK_ENTER_STATE:
+
+                ////////////////////////////////////////////////////////////////////////////////////
+                //  Patch for multiple simultanious CRN's on one Line Device
+                //  While entering the "idle" state we verify that there is not a call waiting
+                //  that could have been receive during the "release" state of the last call.
+                //  Julien Chavanton - August 25 2005 - jchavanton@gmail.com
+                ////////////////////////////////////////////////////////////////////////////////////
+
+                ////////////////////////////////////////////////////////////////////////////////////
+                // 1- Verify if call as been offered during the "release" state and jump to ring
+                ////////////////////////////////////////////////////////////////////////////////////
+                if(crn != -1)
+                {
+                 int call_state;
+                 if(gc_GetCallState( crn, &call_state) != GC_SUCCESS) {
+                  slog(Slog::levelDebug) << "dx(" << id << "): " <<"gc_GetCallState("<<crn<<") == FAILURE"<<endl;
+                 }
+                 else if(call_state != GCST_OFFERED){
+                  releaseCall();
+                 }
+                 else{
+                  if(!group->getAnswer())
+                   return true;
+                  rings = group->getAnswer();
+                  Trunk::flags.trunk = TRUNK_MODE_INCOMING;
+                  group->incIncoming();
+                  Trunk::flags.ready = false;
+                  TimerPort::endTimer();
+                  handler = &DialogicTrunk::ringHandler;
+                  return true;
+                 }
+                }
+                ////////////////////////////////////////////////////////////////////////////////////
+                // 2- Verify if there was call offered during the "release" state before the release was complete, in this case 2                   // crn are active simlutaniously, we can now retreive the second  crn and jump to "ring" state
+                ////////////////////////////////////////////////////////////////////////////////////
+                if(crn_hold != -1)
+                {
+                 crn = crn_hold;
+                 crn_hold = -1;
+                 slog(Slog::levelDebug) <<buffer<<": IDLE TRUNK_ENTER_STATE: call waiting HDL:"<<linedev<<" CRN:"<< crn<< endl;
+                 if(!group->getAnswer())
+                 return true;
+                 rings = group->getAnswer();
+                 Trunk::flags.trunk = TRUNK_MODE_INCOMING;
+                 group->incIncoming();
+                 Trunk::flags.ready = false;
+                 TimerPort::endTimer();
+                 handler = &DialogicTrunk::ringHandler;
+                 return true;
+                }
+                slog(Slog::levelDebug) <<buffer<<": IDLE TRUNK_ENTER_STATE HDL:"<<linedev<<" CRN:"<< crn<< endl;
+                /////////////////////////////////////////////////////
+                // End of patch, entering normal bayonne "idle" state
+                /////////////////////////////////////////////////////
+
 		synctimer = exittimer = 0;
 		if(crn != -1)
 			releaseCall();
