@@ -163,6 +163,8 @@ typedef enum {
 	TRUNK_STEP_THREAD,
 	TRUNK_STEP_SENDFAX,
 	TRUNK_STEP_RECVFAX,
+	TRUNK_STEP_REROUTE,
+	TRUNK_STEP_CONFERENCE,
 	TRUNK_STEP_EXIT = TRUNK_STEP_HANGUP,
 	TRUNK_STEP_DRIVER
 } trunkstep_t;
@@ -587,6 +589,23 @@ typedef	union
 		Trunk *answer;
 		const char *transfer;
 	}	intercom;
+	struct
+	{
+		char option[10];
+		char forwarddest[16 + 1];
+		char backwarddest[16 + 1];
+		char context[24 + 1];
+		char backcontext[24 + 1];
+	}       reroute;
+	struct
+	{
+		char name[256];
+		int option;
+		unsigned int size;
+		int attributes;
+		unsigned int fixed;
+	}	conference;
+
 }	trunkdata_t;
 
 typedef struct
@@ -2115,7 +2134,12 @@ class TrunkImage : public ScriptImage, protected URLStream, protected XMLStream
 private:
 	char *attrib[65];
 
+
+#ifdef	COMMON_64_CLEAN
+	int read(unsigned char *buffer, size_t len);
+#else
 	int read(unsigned char *buffer, int len);
+#endif
 
 	friend class Trunk;
 
@@ -3001,7 +3025,8 @@ public:
 		capGain = 0x0040,	// driver can gain adj
 		capSwitch = 0x2000,
 		capConference = 0x4000,
-		capOffline = 0x8000};
+		capOffline = 0x8000,
+		capReroute = 0x10000};
 
 	/**
 	 * Second tick interval counter.
